// Checker for problem G
// Author: Bartosz Walczak
// Second cmdline argument should be a hint (not an output of a model solution)
#include <algorithm>
#include <cassert>
#include <cstdio>
#include <set>
#include <vector>
using namespace std;

const char* check(vector<pair<int, int>> S, int v, vector<pair<int, int>> T) {
  int max_begin = T[0].first;
  for (int i=1; i<(int)T.size(); ++i) {
    if (T[i].second < max_begin) return "wrong chronology";
    max_begin = max(max_begin, T[i].first);
  }
  vector<pair<int, pair<int, int>>> events;
  for (int i=0; i<(int)T.size(); ++i) {
    events.push_back(make_pair(T[i].first, make_pair(0, i)));
    events.push_back(make_pair(T[i].second, make_pair(1, i)));
  }
  sort(S.begin(), S.end());
  sort(T.begin(), T.end());
  if (S != T) return "wrong set of intervals";
  sort(events.begin(), events.end());
  set<int> ac;
  for (auto const& e : events) {
    if (e.second.first == 0) {
      ac.insert(e.second.second);
      int span = *ac.rbegin() - *ac.begin();
      if (span > v) return "bandwidth greater than declared";
    }
    else ac.erase(e.second.second);
  }
  return nullptr;
}

int main(int argc, char** argv) {
  FILE* in = fopen(argv[1], "r");
  FILE* hint = fopen(argv[2], "r");
  FILE* out = fopen(argv[3], "r");

  int all;
  fscanf(in, "%d", &all);
  int bad=0, first;
  const char* msg;
  
  for (int t=1; t<=all; ++t) {
    int n;
    fscanf(in, "%d", &n);
    vector<pair<int, int>> S(n);
    for (int i=0; i<n; ++i) {
      fscanf(in, "%d%d", &S[i].first, &S[i].second);
    }
    int h, o;
    fscanf(hint, "%d", &h);
    fscanf(out, "%d", &o);
    assert(0 <= o && o < n);
    vector<pair<int, int>> T(n);
    for (int i=0; i<n; ++i) {
        fscanf(out, "%d%d", &T[i].first, &T[i].second);
    }
    const char* res = check(std::move(S), o, std::move(T));
    if (!res) {
      if (o>h) res = "bandwidth greater than optimal";
      if (o<h) {
        printf("hint is wrong!\n");
        return 1;
      }
    }
    if (res) {
      if (bad==0) {
        first = t;
        msg = res;
      }
      ++bad;
    }
  }
 
  fclose(in);
  fclose(hint);
  fclose(out);
 
  if (bad>0) {
    printf("Bad answers: %d/%d (%.2f%%)\n", bad, all, 100.0*bad/all);
    printf("First bad answer: Test #%d: %s\n", first, msg);
    return 1;
  }
  printf("OK.\n");
  return 0;
}
